USE master
GO

IF EXISTS (SELECT * FROM sysobjects WHERE name = 'fn_Split' AND type = 'TF') 
BEGIN
    EXEC sp_configure 'allow updates',1
    RECONFIGURE WITH OVERRIDE
    DROP FUNCTION system_function_schema.fn_Split
    EXEC sp_configure 'allow updates',0
    RECONFIGURE WITH OVERRIDE
END

GO

CREATE FUNCTION fn_Split (@String      varchar(8000),
                          @Delim       varchar(100) = ',')

RETURNS @Array TABLE (ItemId       smallint    IDENTITY(1,1),   --Array index
                      Item         varchar(1000))               --Array element contents

/* Name: Split
 *
 * Purpose:   Accepts a delimited string and splits it at the specified
 *            delimiter points.  Returns the individual items as a table data
 *            type with the ItemId column as the array index and the Item
 *            column as the data.
 * 
 * Written by: Vince Iacoboni  01/15/2003  (snarfed from Karen Gayda 05/31/2001)
 *
 * Usage:     SELECT ItemID, Item
 *              FROM dbo.Split('11111,22222,3333', ';') 
 *              ORDER BY ItemId
 *
 * Modification history:
 *
 */
AS
BEGIN

    DECLARE @Index     smallint,
            @Start     smallint,
            @DelimSize smallint

    SET @DelimSize  = LEN(@Delim)

    --loop through source string and add elements to destination table array
    WHILE LEN(@String) > 0
    BEGIN
        SET @Index = CHARINDEX(@Delim, @String)

        IF @Index = 0
        BEGIN
            INSERT   @Array 
              SELECT @String
            BREAK
        END
        ELSE
        BEGIN
            INSERT   @Array 
              SELECT SUBSTRING(@String, 1, @Index - 1)
            SET @Start = @Index + @DelimSize
            SET @String = SUBSTRING(@String, @Start, LEN(@String) - @Start + 1)
        END
    END
    
    RETURN
END
GO
GRANT SELECT ON fn_Split TO public
GO
EXEC sp_changeobjectowner 'fn_Split','system_function_schema'
GO
